the-ark
===================

Install Instructions
: pip install theark

The Ark is a library of commonly used tools for automating a website. These tools include:

Email Client
: Quick way of sending test results to an email address or a list of email addresses

Field Handlers
: Takes in different field types for form automation and handles them appropriately

Input Generator
: Creates a random user to input in a form.

Picard Client
: Posts to a created Picard schema.

Rhino Client
: Post test results to the Rhino front-end.

S3 Client
: Sending files to and getting files from S3.

Screen Capture
: Getting a full page, single viewport or scrolling screenshot of a webpage.

Selenium Helpers
: A Selenium wrapper that simplifies basic Selenium commands and raises improved exceptions

**The packages in the requirements.txt will need to be installed to get the most out of The Ark.**

> Written with [StackEdit](https://stackedit.io/).